#!/usr/bin/env python
# -*- coding: utf-8 -*-
#


class Image(object):
    """Image reference object. Will output the appropriate image-dictionary when
       added to a JSON feed."""

    def __init__(self, url, **keywords):
        self.height = int(keywords['height'])
        self.width = int(keywords['width'])
        if 'cropCenter' in keywords:
            self.cropCenter = keywords['cropCenter']
        self.url = url

    def imdb_json(self):
        img = { 'url': self.url, 'width': self.width, 'height': self.height }
        if 'cropCenter' in self.__dict__:
            img[ 'cropCenter' ] = float(self.cropCenter)
        return img


class Link(object):
    def __init__(self, title, url, **keywords):
        self.title = title
        self.url = url
        self.subtitle = keywords['subtitle'] if 'subtitle' in keywords else None
        self.startDate = keywords['start'] if 'start' in keywords else None
        self.endDate = keywords['end'] if 'end' in keywords else None

    def imdb_json(self):
        lnk = { 'title': self.title, 'targetUrl': self.url }
        if self.subtitle:
            lnk['subtitle'] = self.subtitle
        if self.startDate:
            lnk['startDate'] = self.startDate
        if self.endDate:
            lnk['endDate'] = self.endDate
        return lnk


class Insets(object):
    """Insets object, which will print out in appropriate inset format
       when added into a JSON feed."""

    def __init__(self, top, left, bottom, right):
        self.top = top
        self.left = left
        self.bottom = bottom
        self.right = right

    def imdb_json(self):
        return "{{{0},{1},{2},{3}}}".format( self.top, self.left, self.bottom, self.right )


Insets.Zero = Insets(0, 0, 0, 0)

