#!/usr/bin/env python
# -*- coding: utf-8 -*-

import json
import datetime
#from pytz import timezone

class IMDbEncoder(json.JSONEncoder):
    """The IMDbEncoder class implements the JSON encoder protocol, which is
       used to serialize our IMDb-related objects into standard JSON. Without
       providing this method in json.dump methods (cls=IMDbEncoder), we would
       not be able to validly write all the objects we've created.

       This works by expecting objects to implement an imdb_json() method
       that will return a valid JSON object (usually a dict/list object).
       These objects may then contain further objects requiring serialization,
       but that is handled for us by the JSON module.
       """

    # Implement the required methods for subclasses of json.JSONEncoder
    def default(self, obj):
        if hasattr(obj, 'imdb_json') and hasattr(obj.imdb_json, '__call__'):
            return obj.imdb_json()
        if isinstance(obj, datetime.datetime):
            return obj.strftime('%Y-%m-%dT%H:%M:%SZ')

# Timezones are a tricky subject. We'll need to figure out proper handling for this...
#           if obj.tzinfo is not None: # Convert timezone if available...
#               return obj.astimezone(timezone('UTC')).strftime("%Y-%m-%dT%H:%M:%SZ")
#           else:
#               # Naive datetime - assume UTC
#               return obj.strftime('%Y-%m-%dT%H:%M:%SZ')
        return super(self.__class__, self).default(obj)


def pretty_print(obj):
    """Prints out a JSON object (or something convertable to it.
    """
    print json.dumps(obj, sort_keys=True, indent=4, separators=(',', ': '), cls=IMDbEncoder)

