#!/usr/bin/env python
# -*- coding: utf-8 -*-


class Color(object):
    def __init__(self, name, components, alpha):
        """Colors have a name (rgbf, grayf, etc), and components."""
        self.name = name
        self.components = components;
        self.alpha = alpha

    def __str__(self):
        """By default the string representation of a color is the
        name, with the components in the parenthesis after it."""
        return "%s(%s, %g)" % (self.name, ', '.join(map(lambda x: "%g" % x, self.components)), self.alpha)

    def colorWithAlpha(self, alpha):
        return Color(self.name, tuple(self.components), alpha)

    def imdb_json(self):
        """The JSON representation of a color is its string."""
        return self.__str__()


class RGB(Color):
    """RGB colors have red, green, blue, and an optional alpha value (defaults to 1.0)."""
    def __init__(self, red, green, blue, *args):
        alpha = args[0] if len(args) > 0 else 1.0
        super(self.__class__, self).__init__('rgbf', (red, green, blue), alpha)


class Gray(Color):
    """Gray colors have white and an optional alpha value (defaults to 1.0)."""
    def __init__(self, white, *args):
        alpha = args[0] if len(args) > 0 else 1.0
        super(self.__class__, self).__init__('grayf', [white], alpha)



class Gradient(object):
    """Gradients are a set of color stops. Each stop is a tuple with a position
    in the floating-point range [0, 1], and a color at that position."""
    def __init__(self, *stops):
        self.stops = list(stops)  # To modify the list (below), we must convert to a list

        # If the gradient is just colors, interpolate the positions...
        for pos in range(len(stops)):
            stop = stops[pos]
            if isinstance(stop, Color):
                self.stops[pos] = ( (float(pos) / (len(stops) - 1)), stop )

    def __str__(self):
        try:
            return ', '.join( map( lambda x: '%g %s' % x, self.stops ) )
        except TypeError:
            print( 'Error converting gradient!' )
            return ''

    def imdb_json(self):
        return self.__str__()

