#!/usr/bin/env python
# -*- coding: utf-8 -*-


class Theme(object):
    def __init__(self, themeName):
        self.themeName = themeName
        self.colors = {}
        self.gradients = {}
        self.pointSizes = {}
        self.images = {}
        self.insets = {}

    def __getattr__(self, name):
        if name.endswith('Color'):
            return self.__dict__['colors'][name]
        elif name.endswith('Gradient'):
            return self.__dict__['gradients'][name]
        elif name.endswith('PointSize'):
            return self.__dict__['pointSizes'][name]
        elif name.endswith('Insets'):
            return self.__dict__['insets'][name]
        else:
            raise AttributeError

    def __setattr__(self, name, value):
        if name.endswith('Color'):
            self.__dict__['colors'][name] = value
        elif name.endswith('Gradient'):
            self.__dict__['gradients'][name] = value
        elif name.endswith('PointSize'):
            self.__dict__['pointSizes'][name] = value
        elif name.endswith('Insets'):
            self.__dict__['insets'][name] = value
        else:
            super(self.__class__, self).__setattr__(name, value)

    def themeByMergingFromTheme(self, theme):
        newTheme = self.__class__(theme.themeName)

        for key in newTheme.__dict__.keys():
            if isinstance(newTheme.__dict__[key], dict) and key in self.__dict__ and key in theme.__dict__:
                newTheme.__dict__[key] = dict(self.__dict__[key].items() + theme.__dict__[key].items())

        return newTheme

    def addImage(self, name, image):
        self.images[name] = image

    def imdb_json(self):
        return { 'Color': self.colors,
                 'Gradient': self.gradients,
                 'PointSize': self.pointSizes,
                 'Image': self.images,
                 'Insets': self.insets,
                }


