#!/usr/bin/env python
# -*- coding: utf-8 -*-

from colors import *
from theme import *
from ConfigUtil import Insets


light = None
dark = None


def PerDevice( phone=None, pad=None ):
    """Split values per device. Requires both iPhone/iPad to be declared."""

    # Handle the case of embedded PerDevice calls (usually via accessing an
    # existing theme variable in another, embedded in a PerDevice() call.
    if isinstance(phone, dict):
        phone = phone['phone']
    if isinstance(pad, dict):
        pad = pad['pad']

#    if not phone or not pad:
#        raise ValueError
    return { 'phone': phone, 'pad': pad }


def initialize():
    global light, dark
    light = Theme('light')
    dark = Theme('dark')

    # Setup some default colors for the themes. These can then be reused later
    # to manage the various other text colors...
    dark.darkTextColor = Gray(1)
    dark.slightlyFadedTextColor = Gray(0.87)
    dark.veryFadedTextColor = Gray(0.333)
    dark.fadedTextColor = Gray(0.666)
    dark.fadedTextAlphaColor = Gray(1.0, 0.5)
    dark.mediumTextColor = Gray(0.5)
    dark.invertedTextColor = Gray(0)
    dark.disabledOverlayBackgroundColor = Gray(0.11, 0.85)
    
    light.darkTextColor = PerDevice( phone=Gray(0), pad=Gray(0.2) )
    light.slightlyFadedTextColor = PerDevice( phone=Gray(0.13), pad=Gray(0.3) )
    light.veryFadedTextColor = Gray(0.5)
    light.fadedTextColor = PerDevice( phone=Gray(0.25), pad=Gray(0.4) )
    light.fadedTextAlphaColor = Gray(0.0, 0.5)
    light.mediumTextColor = Gray(0.5)
    light.invertedTextColor = Gray(1)
    light.disabledOverlayBackgroundColor = Gray(0.89, 0.85)

    dark.collectionCellShadowRadiusPointSize = 0 #PerDevice( phone=3.0, pad=6.0 )
    dark.collectionCellShadowOpacityPointSize = 0 #PerDevice( phone=0.5, pad=0.8 )
    dark.tableCellShadowRadiusPointSize = 0 #dark.collectionCellShadowRadiusPointSize
    dark.tableCellShadowOpacityPointSize = 0 #dark.collectionCellShadowOpacityPointSize
    light.collectionCellShadowRadiusPointSize = 0 # 3.0
    light.collectionCellShadowOpacityPointSize = 0 #0.5
    light.tableCellShadowRadiusPointSize = 0 #3.0
    light.tableCellShadowOpacityPointSize = 0 #0.5

    dark.tableTitleCellPosterInsets = Insets(10, 10, 10, 10)
    light.tableTitleCellPosterInsets = Insets(10, 10, 10, 10)
    dark.favoriteButtonTintColor = Gray(0.8)
    light.favoriteButtonTintColor = Gray(0.3)

    # Setup the shared colors...
    for thm in (dark, light):
        thm.bodyPointSize = 14        
        thm.bodySmallPointSize = PerDevice(phone=10, pad=12)
        thm.headerPointSize = PerDevice(phone=16, pad=30)
        thm.headerSmallPointSize = PerDevice(phone=13, pad=thm.bodyPointSize)
        thm.seeAllVerticalOffsetPointSize = PerDevice(phone=1, pad=3)
        thm.headerBarSubtitlePointSize = 14
        thm.headerBarTitlePointSize = 16
        thm.listAccessoryPointSize = 14
        thm.listBodyPointSize = 14
        thm.listSubPointSize = 13
        thm.listHeaderPointSize = 16
        thm.metacriticPointSize = 16
        thm.metacriticReviewCountPointSize = 10

        thm.imdbRatingColor = RGB(0.780, 0.616, 0.122)
        thm.userRatingColor = RGB(0.314, 0.478, 0.863)

        thm.defaultTitleCellInsets = Insets(6, 10, 6, 10)

        thm.attentionTextColor = RGB(0.122, 0.118, 0.110)
        thm.attentionHighlightTextColor = Gray(0.5)
        thm.attentionGradient = Gradient( RGB(0.992, 0.8, 0.294), RGB(0.792, 0.639, 0.231) )
        thm.attentionHighlightGradient = Gradient( RGB(0.792, 0.639, 0.231), RGB(0.922, 0.8, 0.294) )

        thm.badgeBackgroundColor = RGB(0.588, 0.616, 0.616)
        thm.buttonAndArrowsColor = RGB(0.302, 0.631, 0.631)
        thm.chevronColor = Gray(0.5)
        thm.disabledOverlayBackgroundColor = thm.disabledOverlayBackgroundColor
        thm.fadedBodyTextColor = thm.mediumTextColor
        thm.veryFadedBodyTextColor = thm.veryFadedTextColor
        thm.constWatchHeaderTextColor = PerDevice(pad=Gray(1), phone=thm.fadedTextColor)
        thm.constWatchHeaderTextPointSize = 14
        thm.constWatchBodyTextColor = PerDevice(pad=Gray(1), phone=thm.fadedTextColor)
        thm.constWatchBodyTextPointSize = 12
        thm.constWatchBackgroundColor = thm.veryFadedTextColor
        thm.constEpisodesHeaderTextColor = thm.darkTextColor
        thm.constEpisodesBodyTextColor = thm.fadedTextColor
        thm.constRatingVeryFadedTextColor = thm.veryFadedTextColor
        thm.contentQualityTextColor = Gray(.7)
        thm.constWidgetHeaderPointSize = PerDevice(phone=18, pad=22)

        # Red for heart
        thm.favoriteButtonSelectedTintColor = RGB(.820, .004, .004)

        # Identical gradients...
        thm.awardBackgroundGradient = Gradient( RGB(0.949, 0.918, 0.769), RGB(0.949, 0.894, 0.592) )
        thm.darkAwardBackgroundGradient = Gradient( Gray(0.467), Gray(0.417), Gray(0) )
        thm.darkBackgroundGradient = Gradient( (0, Gray(0.467)), (0.05, Gray(0.417)), (1, Gray(0)) )
        thm.lightBackgroundGradient = Gradient( Gray(1), Gray(0.95) )
        thm.tableHighlightGradient = Gradient( RGB(0.07, 0.56, 0.94), RGB(0.0, 0.37, 0.91) )

        # Some text colors defined by the theme's main text setup (above)
        thm.headerTextColor = thm.darkTextColor
        thm.bodyTextColor = thm.slightlyFadedTextColor
        thm.selectedTextColor = thm.invertedTextColor
        thm.pullQuoteTextColor = thm.mediumTextColor

        thm.warningTextColor = RGB(0.682, 0.1, 0.1, 0.9)
        thm.blueTextColor = RGB(0.22, 0.33, 0.53)
        thm.blueCheckColor = RGB(0.0, 0.48, 1.0)

        thm.tableFooterTextColor = thm.fadedTextColor
        thm.tableHeaderTextColor = thm.slightlyFadedTextColor
        thm.tableCellThinBorderColor = Gray(0.85)
        thm.tableCellThickFirstBorderColor = Gray(0.29)
        thm.tableCellThickSecondBorderColor = Gray(0.44)

        thm.featuredBoxShadowColor = RGB(0.259, 0.004, 0.012)
        thm.modalTableHeaderTextColor = thm.tableHeaderTextColor
        thm.modalTableFooterTextColor = thm.slightlyFadedTextColor
        thm.modalBodyTextColor = thm.darkTextColor
        thm.modalFadedBodyTextColor = thm.mediumTextColor
        thm.rowDividerColor = RGB(0.678, 0.710, 0.710)
        thm.rowShadowColor = thm.rowDividerColor
        thm.selectedBackgroundColor = RGB(0.106, 0.780, 0.780)

        thm.pullQuoteTextColor = thm.mediumTextColor
    
        thm.adOverlayBackgroundColor = PerDevice(phone=Gray(0.4, 1.0), pad=Gray(.75, 1.0))

    ## Table specific colors
    dark.tableCellBackgroundColor = PerDevice(pad=Gray(0.2), phone=Gray(0.15))
    dark.tableCellLightTintColor = Gray(0.7)
    dark.tableCellDarkTintColor = Gray(0.5)
    dark.tableCellSelectedBackgroundGradient = Gradient( Gray(0.81), Gray(0.67) )
    dark.tableBackgroundColor = PerDevice(pad=Gray(0.2), phone=Gray(0.10))
    dark.tableSeparatorColor = Gray(1, 0.15)
    
    light.tableCellBackgroundColor = PerDevice(pad=Gray(0.93), phone=Gray(1))
    light.tableCellLightTintColor = Gray(0.07) # Lower number makes the buttons darker
    light.tableCellDarkTintColor = Gray(0.5)
    light.tableCellSelectedBackgroundGradient = Gradient( Gray(0.333), Gray(0.19) )
    light.tableBackgroundColor = RGB(0.788, 0.808, 0.808)
    light.tableSeparatorColor = PerDevice(pad=Gray(0.49), phone=Gray(0.78))

    ## Overall Page
    dark.windowTintColor = Gray(0)
    dark.statusBarBackgroundColor = Gray(0.25, 0.95)
    dark.statusBarBorderColor = Gray(0.5, 0.9)
    dark.pageBackgroundColor = PerDevice(pad=Gray(0.2), phone=Gray(0.10))
    dark.groupTableBackgroundColor = Gray(0.10) # Affects separators on home page
    dark.groupTableSeparatorColor = Gray(1, 0.1)
    dark.pageIndicatorTintColor = Gray(1, 0.7)
    dark.headerBarSegmentedControlTintColor = Gray(0.8) # Controls the text
    dark.headerBarSegmentedControlColor = Gray(0.3)  # Controls the seg divider
    dark.headerBarSegmentedControlHighlightedColor = Gray(0.7)
    
    light.windowTintColor = Gray(0)
    light.statusBarBackgroundColor = Gray(0.45, 0.95)
    light.statusBarBorderColor = Gray(0.6, 1)
    light.pageBackgroundColor = PerDevice(pad=Gray(0.922), phone=Gray(0.93))
    light.groupTableBackgroundColor = PerDevice(pad=Gray(0.85), phone=Gray(0.93))
    light.groupTableSeparatorColor = PerDevice(pad=Gray(0.72))
    light.pageIndicatorTintColor = Gray(0, .7)
    light.headerBarSegmentedControlTintColor = Gray(0.97)
    light.headerBarSegmentedControlColor = Gray(0.65)
    light.headerBarSegmentedControlHighlightedColor = Gray(0.65)

    ## Auxiliary page setup
    tmp = Gray(0.16)
    dark.auxiliaryPageBackgroundColor = tmp
    dark.auxiliarySectionHeaderGradient = Gradient( (0, tmp), (0.8, tmp), (1, tmp.colorWithAlpha(0)) )
    dark.auxiliarySeparatorGradient = Gradient( Gray(0.09), tmp.colorWithAlpha(0) )
    dark.auxiliaryVerticalSeparatorGradient = Gradient( Gray(0.09), tmp.colorWithAlpha(0) )

    tmp = Gray(0.8)
    light.auxiliaryPageBackgroundColor = tmp
    light.auxiliarySectionHeaderGradient = Gradient( (0, tmp), (0.8, tmp), (1, tmp.colorWithAlpha(0)) )
    light.auxiliarySeparatorGradient = Gradient( Gray(0.67), Gray(0.922, 0) )
    light.auxiliaryVerticalSeparatorGradient = Gradient( Gray(0, 0.2), Gray(0, 0) )
    
    ## Widget setup
    dark.widgetBackgroundColor = PerDevice(phone=Gray(1, 0.05), pad=Gray(1, 0))
    light.widgetBackgroundColor = PerDevice(phone=Gray(1, 0.95), pad=Gray(1, 0))

    ## Const page border and text
    dark.constPageBorderColor = Gray(1, 0.2)
    dark.constPageDarkBorderColor = Gray(0.3)
    dark.constPageTranslucentBorderColor = Gray(0.44)
    
    dark.constPageHeaderTextColor = pad=dark.darkTextColor
    dark.constPageTitleBackgroundColor = Gray(1, 0.1)  #iPhone only
    dark.constPageTitleBackgroundGradient = Gradient( Gray(0.2, 0.7), Gray(0.2, 0) )
    dark.constPageWatchBackgroundGradient = Gradient( Gray(0.2, 0.7), Gray(0.2, 0) )
    dark.constBodyTextColor = Gray(1, 0.7)
    dark.constPageTitleImageOverlayColor = Gray(0.2, 0.7)

    light.constPageBorderColor = PerDevice(phone=Gray(0.85), pad=Gray(0.8))
    light.constPageDarkBorderColor = PerDevice(phone=Gray(0.45), pad=Gray(0.8))
    light.constPageTranslucentBorderColor = Gray(0.8)
    light.constPageHeaderTextColor = PerDevice(pad=light.darkTextColor, phone=Gray(0.3))
    light.constPageTitleBackgroundColor = Gray(0, 0.07)
    light.constPageTitleBackgroundGradient = PerDevice(phone=Gradient( Gray(0.922, 0.8), Gray(0.922, 0.9) ), 
                                                       pad=Gradient( Gray(0.922, 0.9), Gray(0.922, 0) ))
    light.constPageWatchBackgroundGradient = PerDevice(phone=Gradient( Gray(0.8, 0.9), Gray(0.8, 0.9) ), 
                                                       pad=Gradient( Gray(0.922, 0.9), Gray(0.922, 0) ))
    light.constBodyTextColor = Gray(0, 0.5)
    light.constPageTitleImageOverlayColor = Gray(0.922, 0.7)

    dark.constPageEpisodeWidgetBackgroundGradient = Gradient( Gray(0.2, 0.7), Gray(0.2, 0.7) )
    light.constPageEpisodeWidgetBackgroundGradient = Gradient( Gray(0.922, 0.8), Gray(0.922, 0.8))

    dark.constPageSectionBackgroundGradient = Gradient( Gray(0.2), dark.pageBackgroundColor)
    light.constPageSectionBackgroundGradient = Gradient( Gray(1), light.pageBackgroundColor )
    
    dark.sectionHeaderBackgroundColor = PerDevice(pad=Gray(0.3, 0.9), phone=Gray(0.13, 0.9)) # Makes sections appear darker
    dark.sectionHeaderTopBorderColor = PerDevice( pad=Gray(0.78), phone=Gray(1, 0.1) )
    dark.sectionHeaderBottomBorderColor = Gray(0.78, 0.2)
    dark.sectionHeaderTextColor = Gray(1)
    dark.sectionHeaderTextPointSize = 12
    
    light.sectionHeaderBackgroundColor = Gray(0.9, 0.9)
    light.sectionHeaderTopBorderColor = Gray(0.78)
    light.sectionHeaderBottomBorderColor = Gray(0.78)
    light.sectionHeaderTextColor = Gray(0)
    light.sectionHeaderTextPointSize = 12

    light.addImage( 'hero-gradient.png', 'hero-gradient-light.png' )
    
    ## Page indicator (side scrollers?)
    dark.currentPageIndicatorTintColor = Gray(1, 0.2)
    light.currentPageIndicatorTintColor = Gray(0, 0.2)

    ## Homepage Hero Widget
    dark.homeHeroBorderGradient = Gradient( Gray(1, 0.2), Gray(1, 0.2) )
    light.homeHeroBorderGradient = Gradient( Gray(0.8), Gray(0.8) )
    
    ## Nav bar
    dark.navbarItemTintColor = Gray(1)
    dark.navbarTintColor = PerDevice( phone=Gray(0.15), pad=Gray(0.20) )
    light.navbarItemTintColor = Gray(1)
    light.navbarTintColor = Gray(0.45)
    
    dark.navbarBackgroundColor = PerDevice( phone=Gray(0.22, 0.98), pad=Gray(0.30) )
    light.navbarBackgroundColor = Gray(0.45, 0.98)

    ## Header Bar
    dark.headerBarBackgroundColor = dark.navbarBackgroundColor
    dark.headerBarTextColor = dark.darkTextColor
    dark.headerBarFadedTextColor = dark.fadedTextColor
    dark.headerBarTopBorderColor = Gray(0.5, 0.5)
    dark.headerBarBottomBorderColor = Gray(0.3)

    light.headerBarBackgroundColor = light.navbarBackgroundColor
    light.headerBarTextColor = light.darkTextColor
    light.headerBarFadedTextColor = light.fadedTextColor
    light.headerBarTopBorderColor = Gray(0.5, 0.5)
    light.headerBarBottomBorderColor = Gray(0.8)

    ## List cell
    for thm in (dark, light):
        thm.listCellFadedHeaderTextColor = thm.fadedTextColor
        thm.listCellFadedTextColor = thm.fadedTextColor
        thm.listCellSlightlyFadedTextColor = thm.slightlyFadedTextColor
        thm.listCellTextColor = thm.darkTextColor
        thm.listCellVeryFadedTextColor = thm.mediumTextColor
        thm.listTableBackgroundColor = thm.pageBackgroundColor
        thm.listCellHeaderTextColor = thm.darkTextColor

    # List description
    dark.listDescriptionPopoverBackgroundColor = Gray(0.25, 0.9)
    dark.listDescriptionPopoverBorderColor = Gray(1.0, 0.2)
    light.listDescriptionPopoverBackgroundColor = Gray(1.0, 0.9)
    light.listDescriptionPopoverBorderColor = Gray(0.0, 0.15)

    dark.listItemBackgroundColor = PerDevice( phone=Gray(0.18), pad=Gray(0.3) )
    light.listItemBackgroundColor = RGB(0.949, 0.953, 0.949)

    dark.metascoreTextColor = dark.fadedTextColor
    light.metascoreTextColor = light.fadedTextColor

    ## Pulldown
    dark.pulldownBackgroundColor = dark.pageBackgroundColor
    light.pulldownBackgroundColor = light.pageBackgroundColor

    dark.posterPlaceholderBackgroundColor = Gray(1.0, 0.15)
    light.posterPlaceholderBackgroundColor = Gray(0.0, 0.10)
    dark.posterPlaceholderIconColor = Gray(1.0, 0.20)
    light.posterPlaceholderIconColor = Gray(0.0, 0.15)

    ## Poster Cell
    for thm in (dark, light):
        thm.posterFadedHeaderTextColor = thm.fadedTextColor
        thm.posterFadedSubtitleTextColor = thm.mediumTextColor
        thm.posterHeaderTextColor = thm.darkTextColor
        thm.posterSectionHeaderTextColor = thm.slightlyFadedTextColor
        thm.posterSubtitleTextColor = thm.fadedTextColor
        thm.posterTextColor = thm.darkTextColor
        thm.listPlaceholderBackgroundColor = thm.posterPlaceholderBackgroundColor
        thm.listPlaceholderIconColor = thm.posterPlaceholderIconColor
        thm.photoGalleryPlaceholderBackgroundColor = thm.posterPlaceholderBackgroundColor

    ## Rounded Cells
    dark.roundedCellBackgroundColor = PerDevice( phone=Gray(0.15), pad=Gray(0.25) )
    dark.roundedCellFadedTextColor = dark.fadedTextColor
    dark.roundedCellSelectedTextColor = dark.invertedTextColor
    dark.roundedCellTextColor = dark.bodyTextColor
    dark.roundedCellSelectedBackgroundGradient = Gradient( Gray(0.81), Gray(0.67) )

    light.roundedCellBackgroundColor = PerDevice( phone=Gray(0.98), pad=Gray(0.824) )
    light.roundedCellFadedTextColor = light.fadedTextColor
    light.roundedCellSelectedTextColor = light.invertedTextColor
    light.roundedCellTextColor = light.bodyTextColor
    light.roundedCellSelectedBackgroundGradient = Gradient( Gray(0.333), Gray(0.19) )

    ## Showtimes Theater Rounded Cell
    dark.roundedShowtimesCellHeartBackgroundGradient = Gradient( Gray(0.2, 0.23), Gray(0.3, 0.6) )
    light.roundedShowtimesCellHeartBackgroundGradient = Gradient( Gray(0.82, 0.23), Gray(0.9, 0.6) )

    ## Sidebar
    dark.sidebarToolbarTextTintColor = dark.navbarItemTintColor
    dark.sidebarToolbarTintColor = dark.navbarTintColor
    dark.sidebarBackgroundColor = PerDevice( phone=Gray(0.25), pad=Gray(0.133) )
    dark.sidebarCellBackgroundColor = PerDevice( phone=Gray(0.12), pad=Gray(0.06) )
    dark.sidebarHeaderTextColor = dark.darkTextColor
    dark.sidebarHeaderTopBorderColor = Gray(0.247)
    dark.sidebarTextColor = dark.slightlyFadedTextColor
    dark.sidebarFadedTextColor = dark.fadedTextColor
    dark.sidebarHeaderBackgroundGradient = Gradient( Gray(0.204), Gray(0.141) )
    dark.sidebarHeaderSelectionGradient = Gradient( Gray(0.804), Gray(0.702) )

    light.sidebarToolbarTextTintColor = light.navbarItemTintColor
    light.sidebarToolbarTintColor = light.navbarTintColor
    light.sidebarBackgroundColor = PerDevice( phone=Gray(0.93), pad=Gray(0.8) )
    light.sidebarCellBackgroundColor = Gray(0.99)
    light.sidebarHeaderTextColor = light.darkTextColor
    light.sidebarHeaderTopBorderColor = Gray(0.75)
    light.sidebarTextColor = light.slightlyFadedTextColor
    light.sidebarFadedTextColor = light.veryFadedTextColor
    light.sidebarHeaderBackgroundGradient = Gradient( Gray(0.941), Gray(0.804) )
    light.sidebarHeaderSelectionGradient = Gradient( Gray(0.804), Gray(0.702) )

    ## Various timestamp (?)
    dark.timeStampColor = RGB(0.475, 0.525, 0.525)
    light.timeStampColor = RGB(0.475, 0.525, 0.525)

    ## Capped button
    dark.cappedButtonBackgroundColor = Gray(0.21)
    dark.cappedButtonSelectedBackgroundColor = Gray(0.81)

    light.cappedButtonBackgroundColor = Gray(0.81)
    light.cappedButtonSelectedBackgroundColor = Gray(0.21)

    ## Collection borders
    dark.collectionCellBorderGradient = Gradient( Gray(0.32), Gray(0.32) )
    dark.collectionCellSelectionGradient = Gradient( Gray(0.81), Gray(0.67) )

    light.collectionCellBorderGradient = Gradient( Gray(0.83), Gray(0.83) )
    light.collectionCellSelectionGradient = Gradient( Gray(0.41), Gray(0.27) )

    # Config Driven pages
    dark.configBorderGradient = Gradient( dark.tableSeparatorColor, dark.tableSeparatorColor )
    light.configBorderGradient = Gradient ( light.tableSeparatorColor, light.tableSeparatorColor )

    dark.configHomeBorderGradient = dark.configBorderGradient;
    light.configHomeBorderGradient = light.configBorderGradient

    dark.homeTopNewsSeparatorGradient = Gradient(  Gray(0.36), Gray(0.36))
    light.homeTopNewsSeparatorGradient = Gradient( Gray(0.8), Gray(0.8) )

    dark.defaultTableSelectionGradient = dark.collectionCellSelectionGradient
    light.defaultTableSelectionGradient = light.collectionCellSelectionGradient

    dark.collectionCellSeparatorBorderColor = Gray(0.33)   # Affects Home page separators
    light.collectionCellSeparatorBorderColor = Gray(0.73)

    # Usually represents the chart title in most cases
    dark.tableHeaderBackgroundColor = Gray(0.2)
    dark.tableHeaderTopBorderColor = Gray(0.37)
    dark.tableHeaderBottomBorderColor = Gray(0.3)

    light.tableHeaderBackgroundColor = Gray(0.9)
    light.tableHeaderTopBorderColor = Gray(0.6)
    light.tableHeaderBottomBorderColor = Gray(0.8)


    ## Peekaboos
    dark.peekabooBackgroundGradient = Gradient( Gray(0.18), Gray(0.26) )
    light.peekabooBackgroundGradient = dark.peekabooBackgroundGradient
    dark.peekabooPosterHeaderTextColor = dark.posterHeaderTextColor
    light.peekabooPosterHeaderTextColor = dark.posterHeaderTextColor
    dark.peekabooHeaderTextColor = dark.headerTextColor
    light.peekabooHeaderTextColor = dark.headerTextColor
    dark.peekabooPageBackgroundColor = dark.pageBackgroundColor
    light.peekabooPageBackgroundColor = dark.pageBackgroundColor
    dark.peekabooCollectionCellBorderGradient = dark.collectionCellBorderGradient
    light.peekabooCollectionCellBorderGradient = dark.collectionCellBorderGradient
    dark.peekabooTableSelectionGradient = dark.defaultTableSelectionGradient
    light.peekabooTableSelectionGradient = dark.defaultTableSelectionGradient

    ## Search
    dark.searchBarTextColor = PerDevice(pad=dark.headerTextColor, phone=dark.darkTextColor)
    dark.searchBarBackgroundColor = Gray(1, 0)
    dark.searchBarTintColor = PerDevice(pad=dark.navbarItemTintColor, phone=Gray(0.7))
    light.searchBarTextColor = PerDevice(pad=dark.headerTextColor, phone=light.darkTextColor)
    light.searchBarBackgroundColor = PerDevice(pad=Gray(1,0), phone=Gray(0.8))  # We don't want a background on iPad popup
    light.searchBarTintColor = PerDevice(pad=light.navbarItemTintColor, phone=Gray(0.5))
    
    # Photo Gallery
    dark.photoGalleryBackgroundColor = Gray(1, 0.2)
    light.photoGalleryBackgroundColor = Gray(1, 0.95)
    
    # Videos
    dark.playTrailerTintColor = Gray(1)
    light.playTrailerTintColor = Gray(0)


    ## Images
    dark.addImage( 'epi_nav_prev', 'epi_nav_dark_prev.png' )
    light.addImage( 'epi_nav_prev', 'epi_nav_prev.png' )

    dark.addImage( 'epi_nav_next', 'epi_nav_dark_next.png' )
    light.addImage( 'epi_nav_next', 'epi_nav_next.png' )

    dark.addImage( 'epi_nav_all', 'epi_nav_dark_all.png' )
    light.addImage( 'epi_nav_all', 'epi_nav_all.png' )

    dark.addImage( 'headerbar_icon_TV', 'headerbar_icon_TV.png' )
    light.addImage( 'headerbar_icon_TV', 'headerbar_icon_TV.png' )

    light.addImage( 'button_background', 'button_background_dark.png' )
    dark.addImage( 'button_background', 'button_background_light.png' )

    light.addImage( 'action_overlay.png', 'action_overlay_light.png' )
    dark.addImage( 'action_overlay.png', 'action_overlay_dark.png' )

    light.addImage( 'chevron-icon.png', 'ChevronIconBlack' )
    dark.addImage( 'chevron-icon.png', 'ChevronIconWhite' )

    light.addImage( 'external-icon.png', 'ExternalIconBlack' )
    dark.addImage( 'external-icon.png', 'ExternalIconWhite' )

    light.addImage( 'list-icon.png', 'ListIconBlack' )
    dark.addImage( 'list-icon.png', 'ListIconWhite' )

    light.addImage( 'details-icon.png', 'DetailsIconBlack' )
    dark.addImage( 'details-icon.png', 'DetailsIconWhite' )


def generate_config():
    global light, dark
    if not light or not dark:
        initialize()

    return { 'dark': dark,
             'light': light }

def generate_json_to_path(path=None):
    import sys
    import json
    from IMDbEncoder import IMDbEncoder

    with open(path, 'w') as output:
              data = json.dumps(generate_config(), cls=IMDbEncoder)
              output.write(data)   


if __name__ == '__main__':
    import sys
    from IMDbEncoder import pretty_print
    pretty_print(generate_config())
